@@ -6,16 +6,14 @@ class CoreTransformation:
 		self.construct_class = construct_class
 
 	def __call__(self, *args):
-		if image == None:
-			raise ValueError("You have improperly called the image constructor.")
+
+		if self.construct_class == None:
+			raise ValueError("Constructor improperly called, please retry by properly applying a constructor for the transformation.")
 		else:
-			if self.construct_class == None:
-				raise ValueError("Constructor improperly called, please retry by properly applying a constructor for the transformation.")
-			else:
-				try:
-					return self.construct_class(*args)
-				except Exception:
-					raise ValueError("Your constructor function has an error in it.")
+			try:
+				return self.construct_class(*args)
+			except Exception:
+				raise ValueError("Your constructor function has an error in it.")
 
 			
 class TwoImageTransformation:
